# -*- coding: utf-8 -*-
#
# Univention Admin Modules
#  admin module for mailinglists
#
# Copyright 2004-2016 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

from univention.admin.layout import Tab, Group
import univention.admin.filter
import univention.admin.handlers
import univention.admin.allocators
import univention.admin.localization
import univention.debug

translation = univention.admin.localization.translation('univention.admin.handlers.maildisclaimer')
_ = translation.translate

module = 'maildisclaimer/images'
operations = ['add', 'edit', 'remove', 'search']
childs = 0
short_description = _('Maildisclaimer image')
long_description = ''
default_containers = ["cn=images,cn=maildisclaimer"]
options = {}
module_search_filter = univention.admin.filter.expression('objectClass', 'maildisclaimerFile'),

property_descriptions = {
	'name': univention.admin.property(
		short_description=_('Name'),
		long_description='',
		syntax=univention.admin.syntax.string,
		multivalue=False,
		include_in_default_search=True,
		required=True,
		may_change=True,
		identifies=True
	),
	'content': univention.admin.property(
		short_description=_('Content'),
		long_description='',
		syntax=univention.admin.syntax.TextArea,
		multivalue=False,
		include_in_default_search=False,
		required=False,
		may_change=True,
		identifies=False
	),
}

layout = [
	Tab(_('General'), _('Basic settings'), layout=[
		["name"],
		["content"],
	]),
]

mapping = univention.admin.mapping.mapping()
mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
mapping.register('content', 'fileContent', None, univention.admin.mapping.ListToString)


class object(univention.admin.handlers.simpleLdap):
	module = module

	def __init__(self, co, lo, position, dn='', superordinate=None, attributes=None):
		self.co = co
		self.lo = lo
		self.dn = dn
		self.position = position
		self.mapping = mapping
		self.descriptions = property_descriptions
		univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate)
		self.options = []

	def open(self):
		univention.admin.handlers.simpleLdap.open(self)
		self.save()

	#def _ldap_pre_create(self):
	#	pass

	#def _ldap_post_create(self):
	#	pass

	#def _ldap_pre_remove(self):
	#	pass

	#def _ldap_post_remove(self):
	#	pass

	#def _ldap_post_modify(self):
	#	pass

	#def _ldap_pre_modify(self):
	#	pass

	def _ldap_addlist(self):
		ocs = ['top']
		al = []
		ocs.append('maildisclaimerFile')
		al.insert(0, ('objectClass', ocs))
		return al

	def _ldap_modlist(self):
		ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
		return ml

	def cancel(self):
		pass

def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):

	filter = univention.admin.filter.conjunction('&', [
		univention.admin.filter.expression('objectClass', 'maildisclaimerFile')
	])

	if filter_s:
		filter_p = univention.admin.filter.parse(filter_s)
		univention.admin.filter.walk(filter_p, univention.admin.mapping.mapRewrite, arg=mapping)
		filter.expressions.append(filter_p)

	res = []
	for dn, attrs in lo.search(unicode(filter), base, scope, [], unique, required, timeout, sizelimit):
		res.append(object(co, lo, None, dn, attributes=attrs))
	univention.debug.debug(univention.debug.ADMIN, univention.debug.INFO, 'maildisclaimer: %s' % res)
	return res


def identify(dn, attr, canonical=0):
	return 'maildisclaimerFile' in attr.get('objectClass', [])
