#!/usr/bin/python2.7
# -*- coding: utf-8 -*-
#
# Univention Management Console module:
#   Maildisclaimer
#
# Copyright 2017 bitbone AG
#
# http://www.bitbone.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

import sys
import os
import re
import argparse
import copy

import univention.admin.modules

from univention import uldap

class MigrateTemplates(object):

    def __init__(self, template_path, image_path):
        self.template_path = template_path
        self.image_path = image_path

        self.co = None

        self.lo, self.pos = univention.admin.uldap.getAdminConnection()
        self.posImages = copy.deepcopy(self.pos)
        self.pos.setDn('cn=templates,cn=maildisclaimer,%s' % self.pos.getBase())
        self.posImages.setDn('cn=images,cn=maildisclaimer,%s' % self.pos.getBase())

        univention.admin.modules.update()

        self.md = univention.admin.modules.get('maildisclaimer/templates')
        univention.admin.modules.init(self.lo, self.pos, self.md)

        self.udm_images = univention.admin.modules.get('maildisclaimer/images')
        univention.admin.modules.init(self.lo, self.posImages, self.udm_images)

    def get_global_template(self):
        template_global = os.path.realpath("%s/global.txt" % self.template_path)
        m = re.match("^.*/(.*?)\..*?$", template_global)
        if m:
            return m.group(1)
        else:
            return None

    def get_template_names(self):
        files = os.listdir(self.template_path)
        files = filter( lambda x: not os.path.islink("%s/%s" % (self.template_path, x)) and not os.path.isdir("%s/%s" % (self.template_path, x)), files )

        files = map( lambda x: x.rsplit(".", 1)[0], files)

        return set(files)

    def get_images_files(self):
        files = os.listdir(self.image_path)
        files = filter( lambda x: not os.path.islink("%s/%s" % (self.image_path, x)) and not os.path.isdir("%s/%s" % (self.image_path, x)), files )

        return files

    def migrate_templates(self):
        global_template = self.get_global_template()

        for f in self.get_template_names():
            try:
                print "Importing template %s" % (f)
                fd_txt = open("%s/%s.txt" % (self.template_path, f))
                fd_html = open("%s/%s.html" % (self.template_path, f))

                md_obj = self.md.object(self.co, self.lo, self.pos)
                md_obj.open()

                md_obj["name"] = f
                md_obj["text"] = fd_txt.read()
                md_obj["html"] = fd_html.read()

                if f == global_template:
                    md_obj["global"] = "TRUE"
                else:
                    md_obj["global"] = "FALSE"

                md_obj.create()

                fd_txt.close()
                fd_html.close()
            except univention.admin.uexceptions.objectExists, e:
                print "-- Template %s already exists, skipping" % f

    def migrate_images(self):
        for i in self.get_images_files():
            try:
                print "Importing image %s" % (i)
                fd = open("%s/%s" % (self.image_path, i))

                image_obj = self.udm_images.object(self.co, self.lo, self.posImages)
                image_obj["name"] = i
                image_obj["content"] = fd.read()
                image_obj.create()

                fd.close()
            except univention.admin.uexceptions.objectExists, e:
                print "-- Image %s already exists, skipping" % i

    def migrate(self):
        self.migrate_templates()
        self.migrate_images()

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("directory", help="directory to import from")
    args = parser.parse_args()

    image_path = "%s/images" % args.directory
    template_path = "%s/templates" % args.directory

    upgrade = MigrateTemplates(template_path, image_path)
    upgrade.migrate()


